"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var webrtc_common_1 = require("./webrtc.common");
var observable_1 = require("tns-core-modules/data/observable");
var view_1 = require("tns-core-modules/ui/core/view");
var utils_1 = require("tns-core-modules/utils/utils");
var permissions = require("nativescript-permissions");
var android_1 = require("./src/android");
var app = require("tns-core-modules/application");
__export(require("./src/android"));
var webrtc_common_2 = require("./webrtc.common");
exports.IceConnectionState = webrtc_common_2.IceConnectionState;
exports.IceServer = webrtc_common_2.IceServer;
exports.IceGatheringState = webrtc_common_2.IceGatheringState;
exports.Quality = webrtc_common_2.Quality;
exports.SignalingState = webrtc_common_2.SignalingState;
exports.WebRTCDataChannelMessageType = webrtc_common_2.WebRTCDataChannelMessageType;
exports.WebRTCDataChannelState = webrtc_common_2.WebRTCDataChannelState;
exports.WebRTCSdpType = webrtc_common_2.WebRTCSdpType;
exports.WebRTCState = webrtc_common_2.WebRTCState;
var WebRTC = (function (_super) {
    __extends(WebRTC, _super);
    function WebRTC(options) {
        if (options === void 0) { options = { enableAudio: true, enableVideo: true }; }
        var _this = _super.call(this) || this;
        var nativeIceServers;
        if (options.iceServers) {
            nativeIceServers = new java.util.ArrayList();
            options.iceServers.forEach(function (iceServer) {
                var server = org.webrtc.PeerConnection.IceServer.builder(iceServer.url);
                if (iceServer.username) {
                    server.setUsername(iceServer.username);
                }
                if (iceServer.password) {
                    server.setPassword(iceServer.password);
                }
                nativeIceServers.add(server.createIceServer());
            });
        }
        if (nativeIceServers) {
            _this.webrtc = new co.fitcom.fancywebrtc.FancyWebRTC(utils_1.ad.getApplicationContext(), new java.lang.Boolean(!!options.enableVideo).booleanValue(), new java.lang.Boolean(!!options.enableAudio).booleanValue(), nativeIceServers);
        }
        else {
            _this.webrtc = new co.fitcom.fancywebrtc.FancyWebRTC(utils_1.ad.getApplicationContext(), new java.lang.Boolean(!!options.enableVideo).booleanValue(), new java.lang.Boolean(!!options.enableAudio).booleanValue());
        }
        var ref = new WeakRef(_this);
        _this.webrtc.setListener(new co.fitcom.fancywebrtc.FancyWebRTCListener({
            webRTCClientDidReceiveError: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientDidReceiveError',
                    object: observable_1.fromObject({
                        client: owner,
                        error: param1
                    })
                });
            },
            webRTCClientStartCallWithSdp: function (param0, param1) {
                var owner = ref.get();
                var type;
                switch (param1.type) {
                    case org.webrtc.SessionDescription.Type.OFFER:
                        type = webrtc_common_1.WebRTCSdpType.OFFER;
                        break;
                    case org.webrtc.SessionDescription.Type.PRANSWER:
                        type = webrtc_common_1.WebRTCSdpType.PRANSWER;
                        break;
                    case org.webrtc.SessionDescription.Type.ANSWER:
                        type = webrtc_common_1.WebRTCSdpType.ANSWER;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientStartCallWithSdp',
                    object: observable_1.fromObject({
                        client: owner,
                        sdp: param1.description,
                        type: type
                    })
                });
            },
            webRTCClientDataChannelStateChanged: function (param0, param1, param2) {
                var owner = ref.get();
                var state;
                switch (param2) {
                    case org.webrtc.DataChannel.State.CONNECTING:
                        state = webrtc_common_1.WebRTCDataChannelState.CONNECTING;
                        break;
                    case org.webrtc.DataChannel.State.CLOSED:
                        state = webrtc_common_1.WebRTCDataChannelState.CLOSED;
                        break;
                    case org.webrtc.DataChannel.State.CLOSING:
                        state = webrtc_common_1.WebRTCDataChannelState.CLOSING;
                        break;
                    case org.webrtc.DataChannel.State.OPEN:
                        state = webrtc_common_1.WebRTCDataChannelState.OPEN;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientDataChannelStateChanged',
                    object: observable_1.fromObject({
                        client: owner,
                        name: param1,
                        state: state
                    })
                });
            },
            webRTCClientDataChannelMessageType: function (param0, param1, param2, param3) {
                var owner = ref.get();
                var type;
                switch (param3) {
                    case co.fitcom.fancywebrtc.FancyWebRTC.DataChannelMessageType.TEXT:
                        type = webrtc_common_1.WebRTCDataChannelMessageType.TEXT;
                        break;
                    case co.fitcom.fancywebrtc.FancyWebRTC.DataChannelMessageType
                        .BINARY:
                        type = webrtc_common_1.WebRTCDataChannelMessageType.BINARY;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientDataChannelMessageType',
                    object: observable_1.fromObject({
                        client: owner,
                        name: param1,
                        message: param2,
                        type: type
                    })
                });
            },
            webRTCClientOnRemoveStream: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnRemoveStream',
                    object: observable_1.fromObject({
                        client: owner,
                        stream: param1
                    })
                });
            },
            webRTCClientDidReceiveRemoteVideoTrackStream: function (param0, param1, param2) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientDidReceiveRemoteVideoTrackStream',
                    object: observable_1.fromObject({
                        client: owner,
                        remoteVideoTrack: param1,
                        stream: param2
                    })
                });
            },
            webRTCClientDidGenerateIceCandidate: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientDidGenerateIceCandidate',
                    object: observable_1.fromObject({
                        client: owner,
                        iceCandidate: {
                            sdp: param1.sdp,
                            sdpMid: param1.sdpMid,
                            sdpMLineIndex: param1.sdpMLineIndex,
                            serverUrl: param1.serverUrl
                        }
                    })
                });
            },
            webRTCClientOnRenegotiationNeeded: function (param0) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnRenegotiationNeeded',
                    object: observable_1.fromObject({
                        client: owner
                    })
                });
            },
            webRTCClientOnIceCandidatesRemoved: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnRenegotiationNeeded',
                    object: observable_1.fromObject({
                        client: owner,
                        candidates: param1
                    })
                });
            },
            webRTCClientOnIceConnectionChange: function (param0, param1) {
                var owner = ref.get();
                var state;
                switch (param1) {
                    case org.webrtc.PeerConnection.IceConnectionState.NEW:
                        state = webrtc_common_1.IceConnectionState.NEW;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.CHECKING:
                        state = webrtc_common_1.IceConnectionState.CHECKING;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.CONNECTED:
                        state = webrtc_common_1.IceConnectionState.CONNECTED;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.COMPLETED:
                        state = webrtc_common_1.IceConnectionState.COMPLETED;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.FAILED:
                        state = webrtc_common_1.IceConnectionState.FAILED;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.DISCONNECTED:
                        state = webrtc_common_1.IceConnectionState.DISCONNECTED;
                        break;
                    case org.webrtc.PeerConnection.IceConnectionState.CLOSED:
                        state = webrtc_common_1.IceConnectionState.CLOSED;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientOnIceConnectionChange',
                    object: observable_1.fromObject({
                        client: owner,
                        state: state
                    })
                });
            },
            webRTCClientOnIceConnectionReceivingChange: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnIceConnectionReceivingChange',
                    object: observable_1.fromObject({
                        client: owner,
                        change: param1
                    })
                });
            },
            webRTCClientOnIceGatheringChange: function (param0, param1) {
                var owner = ref.get();
                var state;
                switch (param1) {
                    case org.webrtc.PeerConnection.IceGatheringState.NEW:
                        state = webrtc_common_1.IceGatheringState.NEW;
                        break;
                    case org.webrtc.PeerConnection.IceGatheringState.GATHERING:
                        state = webrtc_common_1.IceGatheringState.GATHERING;
                        break;
                    case org.webrtc.PeerConnection.IceGatheringState.COMPLETE:
                        state = webrtc_common_1.IceGatheringState.COMPLETE;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientOnIceGatheringChange',
                    object: observable_1.fromObject({
                        client: owner,
                        state: state
                    })
                });
            },
            webRTCClientOnSignalingChange: function (param0, param1) {
                var owner = ref.get();
                var state;
                switch (param0) {
                    case org.webrtc.PeerConnection.SignalingState.CLOSED:
                        state = webrtc_common_1.SignalingState.CLOSED;
                        break;
                    case org.webrtc.PeerConnection.SignalingState.HAVE_LOCAL_OFFER:
                        state = webrtc_common_1.SignalingState.HAVE_LOCAL_OFFER;
                        break;
                    case org.webrtc.PeerConnection.SignalingState.HAVE_LOCAL_PRANSWER:
                        state = webrtc_common_1.SignalingState.HAVE_LOCAL_PRANSWER;
                        break;
                    case org.webrtc.PeerConnection.SignalingState.HAVE_REMOTE_OFFER:
                        state = webrtc_common_1.SignalingState.HAVE_REMOTE_OFFER;
                        break;
                    case org.webrtc.PeerConnection.SignalingState.HAVE_REMOTE_PRANSWER:
                        state = webrtc_common_1.SignalingState.HAVE_REMOTE_PRANSWER;
                        break;
                    case org.webrtc.PeerConnection.SignalingState.STABLE:
                        state = webrtc_common_1.SignalingState.STABLE;
                        break;
                }
                owner.notify({
                    eventName: 'webRTCClientOnIceGatheringChange',
                    object: observable_1.fromObject({
                        client: owner,
                        state: state
                    })
                });
            },
            webRTCClientOnCameraSwitchDone: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnCameraSwitchDone',
                    object: observable_1.fromObject({
                        client: owner,
                        done: param1
                    })
                });
            },
            webRTCClientOnCameraSwitchError: function (param0, param1) {
                var owner = ref.get();
                owner.notify({
                    eventName: 'webRTCClientOnCameraSwitchError',
                    object: observable_1.fromObject({
                        client: owner,
                        message: param1
                    })
                });
            }
        }));
        return _this;
    }
    WebRTC.requestPermissions = function (explanation) {
        return permissions.requestPermission([
            android.Manifest.permission.CAMERA,
            android.Manifest.permission.RECORD_AUDIO
        ], explanation);
    };
    WebRTC.hasPermissions = function () {
        return (permissions.hasPermission(android.Manifest.permission.CAMERA) &&
            permissions.hasPermission(android.Manifest.permission.RECORD_AUDIO));
    };
    WebRTC._callbackFn = function (args) {
        co.fitcom.fancywebrtc.FancyRTCApplicationHelper.getInstance().handleResult(args.requestCode, args.resultCode, args.intent);
    };
    WebRTC.init = function () {
        co.fitcom.fancywebrtc.FancyWebRTC.init(utils_1.ad.getApplicationContext());
        if (!this.callback) {
            this.callback = this._callbackFn.bind(this);
        }
        app.android.off(app.AndroidApplication.activityResultEvent, this.callback);
        app.android.on(app.AndroidApplication.activityResultEvent, this.callback);
    };
    WebRTC.prototype.dataChannelSend = function (name, data, type) {
        var nativeType;
        switch (type) {
            case webrtc_common_1.WebRTCDataChannelMessageType.BINARY:
                nativeType =
                    co.fitcom.fancywebrtc.FancyWebRTC.DataChannelMessageType.BINARY;
                break;
            case webrtc_common_1.WebRTCDataChannelMessageType.TEXT:
                nativeType =
                    co.fitcom.fancywebrtc.FancyWebRTC.DataChannelMessageType.TEXT;
                break;
        }
        this.webrtc.dataChannelSend(name, data, nativeType);
    };
    WebRTC.prototype.dataChannelClose = function (name) {
        this.webrtc.dataChannelClose(name);
    };
    WebRTC.prototype.dataChannelCreate = function (name) {
        this.webrtc.dataChannelCreate(name);
    };
    WebRTC.prototype.switchCamera = function (trackId) {
        this.webrtc.switchCamera(trackId);
    };
    WebRTC.prototype.handleAnswerReceived = function (answer) {
        var nativeType;
        switch (answer.type) {
            case webrtc_common_1.WebRTCSdpType.ANSWER:
                nativeType = org.webrtc.SessionDescription.Type.ANSWER;
                break;
            case webrtc_common_1.WebRTCSdpType.OFFER:
                nativeType = org.webrtc.SessionDescription.Type.OFFER;
                break;
            case webrtc_common_1.WebRTCSdpType.PRANSWER:
                nativeType = org.webrtc.SessionDescription.Type.PRANSWER;
                break;
        }
        var sdp = new org.webrtc.SessionDescription(nativeType, answer.sdp);
        this.webrtc.handleAnswerReceived(sdp);
    };
    WebRTC.prototype.connect = function () {
        if (!this.webrtc)
            return;
        this.webrtc.connect();
    };
    WebRTC.prototype.disconnect = function () {
        if (this.webrtc) {
            this.webrtc.disconnect();
        }
    };
    WebRTC.prototype.micEnabled = function (enabled) {
        this.webrtc.micEnabled(enabled);
    };
    WebRTC.prototype.toggleMic = function () {
        this.webrtc.toggleMic();
    };
    WebRTC.prototype.speakerEnabled = function (enabled) {
        this.webrtc.speakerEnabled(enabled);
    };
    WebRTC.prototype.createAnswerForOfferReceived = function (sdp) {
        var nativeSdp = new org.webrtc.SessionDescription(org.webrtc.SessionDescription.Type.OFFER, sdp.sdp);
        this.webrtc.createAnswerForOfferReceived(nativeSdp, new org.webrtc.MediaConstraints());
    };
    WebRTC.prototype.makeOffer = function () {
        if (this.webrtc != null) {
            this.webrtc.makeOffer(new org.webrtc.MediaConstraints());
        }
    };
    WebRTC.prototype.addLocalStream = function (stream) {
        this.webrtc.addLocalStream(stream);
    };
    WebRTC.prototype.addIceCandidate = function (iceCandidate) {
        var candidate = new org.webrtc.IceCandidate(iceCandidate.sdpMid, iceCandidate.sdpMLineIndex, iceCandidate.sdp);
        this.webrtc.addIceCandidate(candidate);
    };
    WebRTC.prototype.enableTrack = function (trackId, enable) {
        this.webrtc.enableTrack(trackId, enable);
    };
    WebRTC.prototype.getUserMedia = function (quality) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.LOWEST;
            switch (quality) {
                case webrtc_common_1.Quality.HIGHEST:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.HIGHEST;
                    break;
                case webrtc_common_1.Quality.MAX_480P:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.MAX_480P;
                    break;
                case webrtc_common_1.Quality.MAX_720P:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.MAX_720P;
                    break;
                case webrtc_common_1.Quality.MAX_1080P:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.MAX_1080P;
                    break;
                case webrtc_common_1.Quality.MAX_2160P:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.MAX_2160P;
                    break;
                default:
                    nativeQuality = co.fitcom.fancywebrtc.FancyWebRTC.Quality.LOWEST;
                    break;
            }
            _this.webrtc.getUserMedia(nativeQuality, new co.fitcom.fancywebrtc.FancyWebRTCListener.GetUserMediaListener({
                webRTCClientOnGetUserMedia: function (param0, param1) {
                    resolve(param1);
                },
                webRTCClientOnGetUserMediaDidReceiveError: function (param0, param1) {
                    reject(param1);
                }
            }));
        });
    };
    return WebRTC;
}(webrtc_common_1.Common));
exports.WebRTC = WebRTC;
var TNSRTCScaling;
(function (TNSRTCScaling) {
    TNSRTCScaling["FIT"] = "fit";
    TNSRTCScaling["FILL"] = "fill";
    TNSRTCScaling["NONE"] = "none";
})(TNSRTCScaling = exports.TNSRTCScaling || (exports.TNSRTCScaling = {}));
var WebRTCView = (function (_super) {
    __extends(WebRTCView, _super);
    function WebRTCView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRTCView.prototype.createNativeView = function () {
        return new co.fitcom.fancywebrtc.FancyWebRTCView(this._context, null);
    };
    WebRTCView.prototype.initNativeView = function () {
        _super.prototype.initNativeView.call(this);
        if (this.nativeView && this._scaling) {
            this.nativeView.setScaling(this._scaling);
        }
    };
    Object.defineProperty(WebRTCView.prototype, "mirror", {
        set: function (mirror) {
            if (this.nativeView) {
                this.nativeView.setMirror(mirror);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebRTCView.prototype, "scaling", {
        set: function (scaling) {
            var nativeScaling = co.fitcom.fancywebrtc.FancyWebRTCView.Scaling.NONE;
            switch (scaling) {
                case TNSRTCScaling.FILL:
                    nativeScaling = co.fitcom.fancywebrtc.FancyWebRTCView.Scaling.FILL;
                    break;
                case TNSRTCScaling.FIT:
                    nativeScaling = co.fitcom.fancywebrtc.FancyWebRTCView.Scaling.FIT;
                    break;
                default:
                    break;
            }
            if (this.nativeView) {
                this.nativeView.setScaling(nativeScaling);
            }
            this._scaling = nativeScaling;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebRTCView.prototype, "videoTrack", {
        set: function (track) {
            if (this.nativeView) {
                this.nativeView.setVideoTrack(track);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebRTCView.prototype, "stream", {
        set: function (stream) {
            this._stream = stream;
            if (stream.videoTracks && stream.videoTracks.size() > 0) {
                this.videoTrack = stream.videoTracks.get(0);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebRTCView.prototype, "srcObject", {
        set: function (value) {
            if (value instanceof android_1.TNSRTCMediaStream || value instanceof android_1.TNSRTCMediaStreamTrack) {
                this.nativeView.setSrcObject(value.instance);
            }
            else if (value instanceof org.webrtc.MediaStream) {
                this.nativeView.setSrcObject(value);
            }
            else if (value instanceof co.fitcom.fancywebrtc.FancyRTCMediaStreamTrack) {
                this.nativeView.setSrcObject(value);
            }
            else if (value instanceof org.webrtc.MediaStreamTrack) {
                this.nativeView.setSrcObject(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    return WebRTCView;
}(view_1.View));
exports.WebRTCView = WebRTCView;
//# sourceMappingURL=webrtc.android.js.map